@@ -3,4 +3,6 @@ from computer_vision_python.PoseDet import Pose_Det
 from computer_vision_python.Serialconn import Serial_object
 from computer_vision_python.Handtracker import Hand_detector
 from computer_vision_python.Facemeshmodule import Face_mesh_det
+from computer_vision_python.cvUtils import stackImages,cornerRect,findContours,\
+ overlayPNG,rotateImage,putTextRect
 import computer_vision_python
